==> smartgwtee-eval-5.1p.zip: com/smartgwt/client/docs/FormIcons.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to FormIcons.
 * @see com.smartgwt.client.widgets.form.fields.events.FormItemIconClickEvent
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#keyPress
 * @see com.smartgwt.client.widgets.form.fields.events.IconClickEvent
 * @see com.smartgwt.client.widgets.form.fields.events.IconKeyPressEvent
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getDisableIconsOnReadOnly
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getDefaultIconSrc
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowOverIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowFocusedIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconHSpace
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconVAlign
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconPrompt
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getSrc
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowOver
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowFocused
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowRTL
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowFocusedWithItem
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getNeverDisable
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getDisableOnReadOnly
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getTabIndex
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getPrompt
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getHspace
 * @see com.smartgwt.client.widgets.form.fields.LinkItem#getDisableIconsOnReadOnly
 * @see com.smartgwt.client.widgets.form.fields.LinkItem#getIconVAlign
 * @see com.smartgwt.client.widgets.form.fields.TextAreaItem#getIconVAlign
 */
public interface FormIcons {
}

==> smartgwtee-eval-12.0p.zip: com/smartgwt/client/docs/FormIcons.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to FormIcons.
 * @see com.smartgwt.client.widgets.form.fields.events.FormItemIconClickEvent
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#keyPress
 * @see com.smartgwt.client.widgets.form.fields.FormItem#setIconShowOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItem#setShowIconsOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItem#setShowPickerIconOnFocus
 * @see com.smartgwt.client.widgets.form.fields.events.IconClickEvent
 * @see com.smartgwt.client.widgets.form.fields.events.IconKeyPressEvent
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon
 * @see com.smartgwt.client.widgets.form.DynamicForm#getCanTabToIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getDisableIconsOnReadOnly
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getDefaultIconSrc
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowOverIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowFocusedIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconHSpace
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconVAlign
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconPrompt
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowIconsOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowDisabledIconsOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowPickerIconOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowDisabledPickerIconOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getCanTabToIcons
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getSrc
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getText
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowOver
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowOverWhen
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowFocused
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowRTL
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowFocusedWithItem
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getCanFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getNeverDisable
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getDisableOnReadOnly
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getTabIndex
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getPrompt
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getShowDisabledOnFocus
 * @see com.smartgwt.client.widgets.form.fields.FormItemIcon#getHspace
 * @see com.smartgwt.client.widgets.form.fields.LinkItem#getDisableIconsOnReadOnly
 * @see com.smartgwt.client.widgets.form.fields.LinkItem#getIconVAlign
 * @see com.smartgwt.client.widgets.form.fields.TextAreaItem#getIconVAlign
 */
public interface FormIcons {
}
